@@ -15,6 +15,7 @@
 package errors
 
 import (
+	"errors"
 	"fmt"
 	"net/http"
 	"net/http/httptest"
@@ -71,7 +72,7 @@ func TestServeError(t *testing.T) {
 	}()
 
 	// defaults to internal server error
-	simpleErr := fmt.Errorf("some error")
+	simpleErr := errors.New("some error")
 	recorder = httptest.NewRecorder()
 	ServeError(recorder, nil, simpleErr)
 	assert.Equal(t, http.StatusInternalServerError, recorder.Code)
@@ -83,8 +84,8 @@ func TestServeError(t *testing.T) {
 	// unrecognized: return internal error with first error only - the second error is ignored
 	compositeErr := &CompositeError{
 		Errors: []error{
-			fmt.Errorf("firstError"),
-			fmt.Errorf("anotherError"),
+			errors.New("firstError"),
+			errors.New("anotherError"),
 		},
 	}
 	recorder = httptest.NewRecorder()
@@ -148,37 +149,37 @@ func TestServeError(t *testing.T) {
 
 func TestAPIErrors(t *testing.T) {
 	err := New(402, "this failed %s", "yada")
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.EqualValues(t, 402, err.Code())
 	assert.EqualValues(t, "this failed yada", err.Error())
 
 	err = NotFound("this failed %d", 1)
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.EqualValues(t, http.StatusNotFound, err.Code())
 	assert.EqualValues(t, "this failed 1", err.Error())
 
 	err = NotFound("")
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.EqualValues(t, http.StatusNotFound, err.Code())
 	assert.EqualValues(t, "Not found", err.Error())
 
 	err = NotImplemented("not implemented")
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.EqualValues(t, http.StatusNotImplemented, err.Code())
 	assert.EqualValues(t, "not implemented", err.Error())
 
 	err = MethodNotAllowed("GET", []string{"POST", "PUT"})
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.EqualValues(t, http.StatusMethodNotAllowed, err.Code())
 	assert.EqualValues(t, "method GET is not allowed, but [POST,PUT] are", err.Error())
 
 	err = InvalidContentType("application/saml", []string{"application/json", "application/x-yaml"})
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.EqualValues(t, http.StatusUnsupportedMediaType, err.Code())
 	assert.EqualValues(t, "unsupported media type \"application/saml\", only [application/json application/x-yaml] are allowed", err.Error())
 
 	err = InvalidResponseFormat("application/saml", []string{"application/json", "application/x-yaml"})
-	assert.Error(t, err)
+	require.Error(t, err)
 	assert.EqualValues(t, http.StatusNotAcceptable, err.Code())
 	assert.EqualValues(t, "unsupported media type requested, only [application/json application/x-yaml] are available", err.Error())
 }
@@ -245,7 +246,7 @@ func TestMarshalJSON(t *testing.T) {
 	require.NoError(t, err)
 	assert.JSONEq(t, fmt.Sprintf(`{"code":1,"message":"a","errors":[%s]}`, expectedJSON), string(jazon))
 
-	p := ParseError{code: 1, message: "x", Name: "a", In: "b", Value: "c", Reason: fmt.Errorf("d")}
+	p := ParseError{code: 1, message: "x", Name: "a", In: "b", Value: "c", Reason: errors.New("d")}
 	jazon, err = p.MarshalJSON()
 	require.NoError(t, err)
 	assert.JSONEq(t, `{"code":1,"message":"x","name":"a","in":"b","value":"c","reason":"d"}`, string(jazon))
